@@ -9,17 +9,19 @@ if __name__ == "__main__":
     g = rdflib.Graph()
     g.load("foaf.n3", format="n3")
 
-    print("Initially there are {} triples in the graph".format(len(g)))
+    print(f"Initially there are {len(g)} triples in the graph")
 
     g.update(
         """
         PREFIX foaf: <http://xmlns.com/foaf/0.1/>
         PREFIX dbpedia: <http://dbpedia.org/resource/>
-        INSERT
-            { ?s a dbpedia:Human . }
-        WHERE
-            { ?s a foaf:Person . }
+        INSERT { 
+            ?s a dbpedia:Human . 
+        }
+        WHERE {
+            ?s a foaf:Person .
+        }
         """
     )
 
-    print("After the UPDATE, there are {} triples in the graph".format(len(g)))
+    print(f"After the UPDATE, there are {len(g)} triples in the graph")
