@@ -4,21 +4,26 @@ See <http://www.w3.org/TR/trig/> for syntax specification.
 """
 
 from collections import defaultdict
+from typing import IO, TYPE_CHECKING, Optional, Union
 
-from rdflib.plugins.serializers.turtle import TurtleSerializer, _GEN_QNAME_FOR_DT, VERB
+from rdflib.graph import ConjunctiveGraph, Graph
+from rdflib.plugins.serializers.turtle import TurtleSerializer
+from rdflib.term import BNode, Node
 
-from rdflib.term import BNode, Literal
 
-__all__ = ['TrigSerializer']
+__all__ = ["TrigSerializer"]
 
 
 class TrigSerializer(TurtleSerializer):
 
     short_name = "trig"
-    indentString = 4 * u' '
+    indentString = 4 * " "
 
-    def __init__(self, store):
+    def __init__(self, store: Union[Graph, ConjunctiveGraph]):
+        self.default_context: Optional[Node]
         if store.context_aware:
+            if TYPE_CHECKING:
+                assert isinstance(store, ConjunctiveGraph)
             self.contexts = list(store.contexts())
             self.default_context = store.default_context.identifier
             if store.default_context:
@@ -39,17 +44,31 @@ class TrigSerializer(TurtleSerializer):
             for triple in context:
                 self.preprocessTriple(triple)
 
-            self._contexts[context]=(self.orderSubjects(), self._subjects, self._references)
+            self._contexts[context] = (
+                self.orderSubjects(),
+                self._subjects,
+                self._references,
+            )
 
     def reset(self):
         super(TrigSerializer, self).reset()
         self._contexts = {}
 
-    def serialize(self, stream, base=None, encoding=None,
-                  spacious=None, **args):
+    def serialize(
+        self,
+        stream: IO[bytes],
+        base: Optional[str] = None,
+        encoding: Optional[str] = None,
+        spacious: Optional[bool] = None,
+        **args,
+    ):
         self.reset()
         self.stream = stream
-        self.base = base
+        # if base is given here, use that, if not and a base is set for the graph use that
+        if base is not None:
+            self.base = base
+        elif self.store.base is not None:
+            self.base = self.store.base
 
         if spacious is not None:
             self._spacious = spacious
@@ -60,15 +79,16 @@ class TrigSerializer(TurtleSerializer):
 
         firstTime = True
         for store, (ordered_subjects, subjects, ref) in self._contexts.items():
-            if not ordered_subjects: continue
+            if not ordered_subjects:
+                continue
 
             self._references = ref
             self._serialized = {}
             self.store = store
             self._subjects = subjects
 
-            if self.default_context and store.identifier==self.default_context:
-                self.write(self.indent() + '\n{')
+            if self.default_context and store.identifier == self.default_context:
+                self.write(self.indent() + "\n{")
             else:
                 if isinstance(store.identifier, BNode):
                     iri = store.identifier.n3()
@@ -76,7 +96,7 @@ class TrigSerializer(TurtleSerializer):
                     iri = self.getQName(store.identifier)
                     if iri is None:
                         iri = store.identifier.n3()
-                self.write(self.indent() + '\n%s {' % iri)
+                self.write(self.indent() + "\n%s {" % iri)
 
             self.depth += 1
             for subject in ordered_subjects:
@@ -85,9 +105,9 @@ class TrigSerializer(TurtleSerializer):
                 if firstTime:
                     firstTime = False
                 if self.statement(subject) and not firstTime:
-                    self.write('\n')
+                    self.write("\n")
             self.depth -= 1
-            self.write('}\n')
+            self.write("}\n")
 
         self.endDocument()
-        stream.write(u"\n".encode('ascii'))
+        stream.write("\n".encode("latin-1"))
