@@ -6,7 +6,6 @@ def testFinalNewline():
     """
     http://code.google.com/p/rdflib/issues/detail?id=5
     """
-    import sys
 
     graph = ConjunctiveGraph()
     graph.add(
@@ -19,19 +18,10 @@ def testFinalNewline():
 
     failed = set()
     for p in rdflib.plugin.plugins(None, rdflib.plugin.Serializer):
-        v = graph.serialize(format=p.name, encoding="latin-1")
-        lines = v.split("\n".encode("latin-1"))
+        v = graph.serialize(format=p.name, encoding="utf-8")
+        lines = v.split("\n".encode("utf-8"))
         if b"\n" not in v or (lines[-1] != b""):
             failed.add(p.name)
     # JSON-LD does not require a final newline (because JSON doesn't)
     failed = failed.difference({"json-ld", "application/ld+json"})
     assert len(failed) == 0, "No final newline for formats: '%s'" % failed
-
-
-if __name__ == "__main__":
-
-    import sys
-    import nose
-
-    if len(sys.argv) == 1:
-        nose.main(defaultTest=sys.argv[0])
