@@ -1,7 +1,9 @@
 from rdflib import Graph, RDF
 
+
 def test_recursive_list_detection():
-        g = Graph().parse(data="""
+    g = Graph().parse(
+        data="""
         @prefix : <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
 
         <> :value _:a .
@@ -13,12 +15,14 @@ def test_recursive_list_detection():
         <> :value [ :first "turtles"; :rest _:c ] .
         _:c :first "all the way down"; :rest _:a .
 
-        """, format="turtle")
+        """,
+        format="turtle",
+    )
 
-        for v in g.objects(None, RDF.value):
-            try:
-                list(g.items(v))
-            except ValueError, e:
-                pass
-            else:
-                assert False, "Expected detection of recursive rdf:rest reference"
+    for v in g.objects(None, RDF.value):
+        try:
+            list(g.items(v))
+        except ValueError as e:
+            pass
+        else:
+            assert False, "Expected detection of recursive rdf:rest reference"
