@@ -43,29 +43,28 @@ target2xml = """\
 
 
 class CollectionTest(TestCase):
-
     def test_collection_render(self):
-        foo = Namespace('http://www.example.org/foo/ns/')
-        ex = Namespace('http://www.example.org/example/foo/')
-        rdf = Namespace('http://www.w3.org/1999/02/22-rdf-syntax-ns#')
+        foo = Namespace("http://www.example.org/foo/ns/")
+        ex = Namespace("http://www.example.org/example/foo/")
+        rdf = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
 
         # Works:  x a rdf:List, a foo:Other ;
         # Fails:  y a foo:Wrapper, foo:wraps x; x a rdf:List, a foo:Other ;
 
         target1 = ConjunctiveGraph()
-        target1.parse(data=target1xml)
+        target1.parse(data=target1xml, format="xml")
         target2 = ConjunctiveGraph()
-        target2.parse(data=target2xml)
+        target2.parse(data=target2xml, format="xml")
 
         g = ConjunctiveGraph()
-        bits = [ex['a'], ex['b'], ex['c']]
-        l = Collection(g, ex['thing'], bits)
-        triple = (ex['thing'], rdf['type'], foo['Other'])
+        bits = [ex["a"], ex["b"], ex["c"]]
+        l = Collection(g, ex["thing"], bits)
+        triple = (ex["thing"], rdf["type"], foo["Other"])
         g.add(triple)
-        triple = (ex['thing'], foo['property'], Literal('Some Value'))
+        triple = (ex["thing"], foo["property"], Literal("Some Value"))
         g.add(triple)
         for b in bits:
-            triple = (b, rdf['type'], foo['Item'])
+            triple = (b, rdf["type"], foo["Item"])
             g.add(triple)
         self.assertEqual(g.isomorphic(target1), True)
 
