@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 import unittest
 
-from nose import SkipTest
 from rdflib.graph import ConjunctiveGraph
 from rdflib.parser import StringInputSource
 import textwrap
+import pytest
 
 prefix = textwrap.dedent(
     """\
@@ -42,7 +42,7 @@ test_string1 = """\
 Betriebsnummer der Einzugsstelle:\nKnappschaft\n980 0000 6\nWICHTIGES DOKUMENT - SORGFÄLTIG AUFBEWAHREN!\n """
 
 
-@unittest.skipIf(True, "Known issue with newlines in text")
+@pytest.mark.xfail(reason="Known issue with newlines in text")
 def test1():
     meta1 = meta.encode("utf-8") % test_string1.encode("utf-8")
     graph = ConjunctiveGraph()
@@ -59,14 +59,10 @@ WICHTIGES DOKUMENT - SORGFÄLTIG AUFBEWAHREN!
 """
 
 
-@unittest.skipIf(True, "Known issue with newlines in text")
+@pytest.mark.xfail(reason="Known issue with newlines in text")
 def test2():
     meta2 = meta.encode("utf-8") % test_string2.encode("utf-8")
     graph = ConjunctiveGraph()
     graph.parse(
         StringInputSource(prefix + "<http://example.org/>" + meta2), format="n3"
     )
-
-
-if __name__ == "__main__":
-    unittest.main()
