@@ -1,4 +1,3 @@
-
 from rdflib.plugins import sparql
 from rdflib.namespace import RDFS, OWL, DC, SKOS
 
@@ -15,4 +14,5 @@ def test_issue():
                 ?property rdfs:label | skos:altLabel ?label .
             }
         """,
-        initNs={"rdfs": RDFS, "owl": OWL, "dc": DC, "skos": SKOS})
+        initNs={"rdfs": RDFS, "owl": OWL, "dc": DC, "skos": SKOS},
+    )
