@@ -6,9 +6,9 @@ from rdflib.namespace import FOAF, RDF
 
 def test_issue579():
     g = Graph()
-    g.bind('foaf', FOAF)
+    g.bind("foaf", FOAF)
     n = Namespace("http://myname/")
-    g.add((n.bob, FOAF.name, Literal('bb')))
+    g.add((n.bob, FOAF.name, Literal("bb")))
     # query is successful.
     assert len(g.query("select ?n where { ?n foaf:name 'bb' . }")) == 1
     # update is not.
