@@ -1,8 +1,6 @@
 import rdflib
 from rdflib.plugins.parsers.notation3 import BadSyntax
 
-import nose.tools
-
 # Test for https://github.com/RDFLib/rdflib/issues/336
 # and https://github.com/RDFLib/rdflib/issues/345
 
@@ -38,10 +36,3 @@ def test_ns_localname_roundtrip():
     g1 = rdflib.Graph()
     g1.parse(data=xmldump, format="xml")
     g1.parse(data=turtledump, format="turtle")
-
-
-if __name__ == "__main__":
-    import nose
-    import sys
-
-    nose.main(defaultTest=sys.argv[0])
