@@ -7,7 +7,7 @@ from rdflib.store import NodePickler
 
 # same as nt/more_literals.nt
 cases = [
-    'no quotes',
+    "no quotes",
     "single ' quote",
     'double " quote',
     'triple """ quotes',
@@ -15,7 +15,7 @@ cases = [
     '"',
     "'",
     '"\'"',
-    '\\',  # len 1
+    "\\",  # len 1
     '\\"',  # len 2
     '\\\\"',  # len 3
     '\\"\\',  # len 3
@@ -24,12 +24,13 @@ cases = [
 
 
 class UtilTestCase(unittest.TestCase):
-
     def test_to_bits_from_bits_round_trip(self):
         np = NodePickler()
 
-        a = Literal(u'''A test with a \\n (backslash n), "\u00a9" , and newline \n and a second line.
-''')
+        a = Literal(
+            """A test with a \\n (backslash n), "\u00a9" , and newline \n and a second line.
+"""
+        )
         b = np.loads(np.dumps(a))
         self.assertEqual(a, b)
 
@@ -49,5 +50,5 @@ class UtilTestCase(unittest.TestCase):
         self.assertEqual(np._objects, np2._objects)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
