@@ -60,7 +60,7 @@ class NQuadsParserTest(unittest.TestCase):
         g.get_context(uri1).add((bob, likes, pizza))
         g.get_context(uri2).add((bob, likes, pizza))
 
-        s = g.serialize(format="nquads", encoding="latin-1")
+        s = g.serialize(format="nquads", encoding="utf-8")
         self.assertEqual(len([x for x in s.split(b"\n") if x.strip()]), 2)
 
         g2 = ConjunctiveGraph()
