@@ -5,6 +5,7 @@ import re
 from rdflib import Graph, Literal, URIRef
 from rdflib.plugins.parsers import ntriples
 from urllib.request import urlopen
+from pathlib import Path
 
 from test import TEST_DIR
 
@@ -32,15 +33,15 @@ class NTTestCase(unittest.TestCase):
     def testIssue78(self):
         g = Graph()
         g.add((URIRef("foo"), URIRef("foo"), Literal("R\u00E4ksm\u00F6rg\u00E5s")))
-        s = g.serialize(format="nt", encoding="latin-1")
-        self.assertEqual(type(s), bytes)
-        self.assertTrue(r"R\u00E4ksm\u00F6rg\u00E5s".encode("latin-1") in s)
+        s = g.serialize(format="nt")
+        self.assertEqual(type(s), str)
+        self.assertTrue("R\u00E4ksm\u00F6rg\u00E5s" in s)
 
     def testIssue146(self):
         g = Graph()
         g.add((URIRef("foo"), URIRef("foo"), Literal("test\n", lang="en")))
-        s = g.serialize(format="nt", encoding="latin-1").strip()
-        self.assertEqual(s, b'<foo> <foo> "test\\n"@en .')
+        s = g.serialize(format="nt").strip()
+        self.assertEqual(s, '<foo> <foo> "test\\n"@en .')
 
     def testIssue1144_rdflib(self):
         fname = "test/nt/lists-02.nt"
@@ -125,7 +126,7 @@ class NTTestCase(unittest.TestCase):
         self.assertTrue(res == None)
 
     def test_w3_ntriple_variants(self):
-        uri = "file://" + os.path.abspath(nt_file("test.ntriples"))
+        uri = Path(nt_file("test.ntriples")).absolute().as_uri()
 
         parser = ntriples.W3CNTriplesParser()
         u = urlopen(uri)
