@@ -13,6 +13,9 @@ class FileParserGuessFormatTest(unittest.TestCase):
     def test_jsonld(self):
         g = Graph()
         self.assertIsInstance(g.parse("test/jsonld/1.1/manifest.jsonld"), Graph)
+        self.assertIsInstance(g.parse("test/jsonld/file_ending_test_01.json"), Graph)
+        self.assertIsInstance(g.parse("test/jsonld/file_ending_test_01.json-ld"), Graph)
+        self.assertIsInstance(g.parse("test/jsonld/file_ending_test_01.jsonld"), Graph)
 
     def test_ttl(self):
         g = Graph()
