@@ -10,9 +10,9 @@ from rdflib import URIRef
 class TestPrefLabel(unittest.TestCase):
     def setUp(self):
         self.g = ConjunctiveGraph()
-        self.u = URIRef("http://example.com/foo")
-        self.g.add([self.u, RDFS.label, Literal("foo")])
-        self.g.add([self.u, RDFS.label, Literal("bar")])
+        self.u = URIRef("https://example.com/foo")
+        self.g.add((self.u, RDFS.label, Literal("foo")))
+        self.g.add((self.u, RDFS.label, Literal("bar")))
 
     def test_default_label_sorting(self):
         res = sorted(self.g.preferredLabel(self.u))
@@ -29,7 +29,7 @@ class TestPrefLabel(unittest.TestCase):
         self.assertEqual(res, tgt)
 
     def test_default_preflabel_sorting(self):
-        self.g.add([self.u, SKOS.prefLabel, Literal("bla")])
+        self.g.add((self.u, SKOS.prefLabel, Literal("bla")))
         res = self.g.preferredLabel(self.u)
         tgt = [
             (
@@ -40,8 +40,8 @@ class TestPrefLabel(unittest.TestCase):
         self.assertEqual(res, tgt)
 
     def test_preflabel_lang_sorting_no_lang_attr(self):
-        self.g.add([self.u, SKOS.prefLabel, Literal("bla")])
-        self.g.add([self.u, SKOS.prefLabel, Literal("blubb", lang="en")])
+        self.g.add((self.u, SKOS.prefLabel, Literal("bla")))
+        self.g.add((self.u, SKOS.prefLabel, Literal("blubb", lang="en")))
         res = sorted(self.g.preferredLabel(self.u))
         tgt = [
             (
@@ -57,8 +57,8 @@ class TestPrefLabel(unittest.TestCase):
         self.assertEqual(res, tgt)
 
     def test_preflabel_lang_sorting_empty_lang_attr(self):
-        self.g.add([self.u, SKOS.prefLabel, Literal("bla")])
-        self.g.add([self.u, SKOS.prefLabel, Literal("blubb", lang="en")])
+        self.g.add((self.u, SKOS.prefLabel, Literal("bla")))
+        self.g.add((self.u, SKOS.prefLabel, Literal("blubb", lang="en")))
         res = self.g.preferredLabel(self.u, lang="")
         tgt = [
             (
@@ -69,7 +69,7 @@ class TestPrefLabel(unittest.TestCase):
         self.assertEqual(res, tgt)
 
     def test_preflabel_lang_sorting_en_lang_attr(self):
-        self.g.add([self.u, SKOS.prefLabel, Literal("blubb", lang="en")])
+        self.g.add((self.u, SKOS.prefLabel, Literal("blubb", lang="en")))
         res = self.g.preferredLabel(self.u, lang="en")
         tgt = [
             (
