@@ -1,8 +1,7 @@
 # -*- coding: UTF-8 -*-
 from rdflib.term import URIRef, BNode, Literal
 from rdflib.namespace import RDF, RDFS
-from six import b, BytesIO
-
+from io import BytesIO
 from rdflib.plugins.serializers.rdfxml import PrettyXMLSerializer
 
 from rdflib.graph import ConjunctiveGraph
@@ -46,7 +45,9 @@ def _mangled_copy(g):
     "Makes a copy of the graph, replacing all bnodes with the bnode ``_blank``."
     gcopy = ConjunctiveGraph()
 
-    def isbnode(v): return isinstance(v, BNode)
+    def isbnode(v):
+        return isinstance(v, BNode)
+
     for s, p, o in g:
         if isbnode(s):
             s = _blank
@@ -117,56 +118,97 @@ class TestPrettyXmlSerializer(SerializerTestBase):
             rdfs:seeAlso _:bnode2 .
 
         """
-    testContentFormat = 'n3'
+    testContentFormat = "n3"
 
     def test_result_fragments(self):
         rdfXml = serialize(self.sourceGraph, self.serializer)
-        assert b('<Test rdf:about="http://example.org/data/a">') in rdfXml
-        assert b('<rdf:Description rdf:about="http://example.org/data/b">') in rdfXml
-        assert b('<name xml:lang="en">Bee</name>') in rdfXml
-        assert b('<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>') in rdfXml
-        assert b('<BNode rdf:nodeID="') in rdfXml, "expected one identified bnode in serialized graph"
-        #onlyBNodesMsg = "expected only inlined subClassOf-bnodes in serialized graph"
-        #assert '<rdfs:subClassOf>' in rdfXml, onlyBNodesMsg
-        #assert not '<rdfs:subClassOf ' in rdfXml, onlyBNodesMsg
+        assert (
+            '<Test rdf:about="http://example.org/data/a">'.encode("latin-1") in rdfXml
+        )
+        assert (
+            '<rdf:Description rdf:about="http://example.org/data/b">'.encode("latin-1")
+            in rdfXml
+        )
+        assert '<name xml:lang="en">Bee</name>'.encode("latin-1") in rdfXml
+        assert (
+            '<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>'.encode(
+                "latin-1"
+            )
+            in rdfXml
+        )
+        assert (
+            '<BNode rdf:nodeID="'.encode("latin-1") in rdfXml
+        ), "expected one identified bnode in serialized graph"
+        # onlyBNodesMsg = "expected only inlined subClassOf-bnodes in serialized graph"
+        # assert '<rdfs:subClassOf>' in rdfXml, onlyBNodesMsg
+        # assert not '<rdfs:subClassOf ' in rdfXml, onlyBNodesMsg
 
     def test_result_fragments_with_base(self):
-        rdfXml = serialize(self.sourceGraph, self.serializer,
-                           extra_args={'base': "http://example.org/", 'xml_base': "http://example.org/"})
-        assert b('xml:base="http://example.org/"') in rdfXml
-        assert b('<Test rdf:about="data/a">') in rdfXml
-        assert b('<rdf:Description rdf:about="data/b">') in rdfXml
-        assert b('<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>') in rdfXml
-        assert b('<BNode rdf:nodeID="') in rdfXml, "expected one identified bnode in serialized graph"
+        rdfXml = serialize(
+            self.sourceGraph,
+            self.serializer,
+            extra_args={
+                "base": "http://example.org/",
+                "xml_base": "http://example.org/",
+            },
+        )
+        assert 'xml:base="http://example.org/"'.encode("latin-1") in rdfXml
+        assert '<Test rdf:about="data/a">'.encode("latin-1") in rdfXml
+        assert '<rdf:Description rdf:about="data/b">'.encode("latin-1") in rdfXml
+        assert (
+            '<value rdf:datatype="http://www.w3.org/2001/XMLSchema#integer">3</value>'.encode(
+                "latin-1"
+            )
+            in rdfXml
+        )
+        assert (
+            '<BNode rdf:nodeID="'.encode("latin-1") in rdfXml
+        ), "expected one identified bnode in serialized graph"
 
     def test_subClassOf_objects(self):
         reparsedGraph = serialize_and_load(self.sourceGraph, self.serializer)
-        _assert_expected_object_types_for_predicates(reparsedGraph,
-                                                     [RDFS.seeAlso, RDFS.subClassOf],
-                                                     [URIRef, BNode])
+        _assert_expected_object_types_for_predicates(
+            reparsedGraph, [RDFS.seeAlso, RDFS.subClassOf], [URIRef, BNode]
+        )
 
     def test_pretty_xmlliteral(self):
         # given:
         g = ConjunctiveGraph()
-        g.add((BNode(), RDF.value, Literal(u'''<p xmlns="http://www.w3.org/1999/xhtml">See also <a href="#aring">Å</a></p>''', datatype=RDF.XMLLiteral)))
+        g.add(
+            (
+                BNode(),
+                RDF.value,
+                Literal(
+                    """<p xmlns="http://www.w3.org/1999/xhtml">See also <a href="#aring">Å</a></p>""",
+                    datatype=RDF.XMLLiteral,
+                ),
+            )
+        )
         # when:
-        xmlrepr = g.serialize(format='pretty-xml')
+        xmlrepr = g.serialize(format="pretty-xml")
         # then:
-        assert u'''<rdf:value rdf:parseType="Literal"><p xmlns="http://www.w3.org/1999/xhtml">See also <a href="#aring">Å</a></p></rdf:value>'''.encode('utf-8') in xmlrepr
+        assert (
+            """<rdf:value rdf:parseType="Literal"><p xmlns="http://www.w3.org/1999/xhtml">See also <a href="#aring">Å</a></p></rdf:value>"""
+            in xmlrepr
+        )
 
     def test_pretty_broken_xmlliteral(self):
         # given:
         g = ConjunctiveGraph()
-        g.add((BNode(), RDF.value, Literal(u'''<p ''', datatype=RDF.XMLLiteral)))
+        g.add((BNode(), RDF.value, Literal("""<p """, datatype=RDF.XMLLiteral)))
         # when:
-        xmlrepr = g.serialize(format='pretty-xml')
+        xmlrepr = g.serialize(format="pretty-xml")
         # then:
-        assert u'''<rdf:value rdf:datatype="http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral">&lt;p '''.encode('utf-8') in xmlrepr
+        assert (
+            """<rdf:value rdf:datatype="http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral">&lt;p """
+            in xmlrepr
+        )
 
 
 def _assert_expected_object_types_for_predicates(graph, predicates, types):
     for s, p, o in graph:
         if p in predicates:
             someTrue = [isinstance(o, t) for t in types]
-            assert True in someTrue, \
-                "Bad type %s for object when predicate is <%s>." % (type(o), p)
+            assert (
+                True in someTrue
+            ), "Bad type %s for object when predicate is <%s>." % (type(o), p)
