@@ -5,8 +5,7 @@ from rdflib.graph import Graph
 from rdflib.term import URIRef
 
 
-DATA =\
-    """<http://example.com#C> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://www.w3.org/2002/07/owl#Class>.
+DATA = """<http://example.com#C> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://www.w3.org/2002/07/owl#Class>.
 <http://example.com#B> <http://www.w3.org/2000/01/rdf-schema#subClassOf> _:fIYNVPxd4.
 <http://example.com#B> <http://www.w3.org/2000/01/rdf-schema#subClassOf> <http://example.com#A>.
 <http://example.com#B> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://www.w3.org/2002/07/owl#Class>.
@@ -20,8 +19,7 @@ _:fIYNVPxd3 <http://www.w3.org/1999/02/22-rdf-syntax-ns#first> <http://example.c
 _:fIYNVPxd3 <http://www.w3.org/1999/02/22-rdf-syntax-ns#rest> <http://www.w3.org/1999/02/22-rdf-syntax-ns#nil>.
 """
 
-DATA_FALSE_ELEMENT =\
-    """
+DATA_FALSE_ELEMENT = """
 <http://example.org/#ThreeMemberList> <http://www.w3.org/1999/02/22-rdf-syntax-ns#first> <http://example.org/#p> .
 <http://example.org/#ThreeMemberList> <http://www.w3.org/1999/02/22-rdf-syntax-ns#rest> _:list2 .
 _:list2 <http://www.w3.org/1999/02/22-rdf-syntax-ns#first> "false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
@@ -36,19 +34,19 @@ def main():
 
 
 class OWLCollectionTest(unittest.TestCase):
-
     def testCollectionRDFXML(self):
-        g = Graph().parse(data=DATA, format='nt')
-        g.namespace_manager.bind('owl', URIRef('http://www.w3.org/2002/07/owl#'))
-        print(g.serialize(format='pretty-xml'))
+        g = Graph().parse(data=DATA, format="nt")
+        g.namespace_manager.bind("owl", URIRef("http://www.w3.org/2002/07/owl#"))
+        print(g.serialize(format="pretty-xml"))
 
 
 class ListTest(unittest.TestCase):
     def testFalseElement(self):
-        g = Graph().parse(data=DATA_FALSE_ELEMENT, format='nt')
+        g = Graph().parse(data=DATA_FALSE_ELEMENT, format="nt")
         self.assertEqual(
-            len(list(g.items(URIRef('http://example.org/#ThreeMemberList')))), 3)
+            len(list(g.items(URIRef("http://example.org/#ThreeMemberList")))), 3
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
