@@ -1,22 +1,22 @@
-
 from rdflib import Graph, URIRef
 import unittest
 
 
 class GraphSlice(unittest.TestCase):
-
     def testSlice(self):
         """
-         We pervert the slice object, 
-         and use start, stop, step as subject, predicate, object
+        We pervert the slice object,
+        and use start, stop, step as subject, predicate, object
 
-         all operations return generators over full triples 
+        all operations return generators over full triples
         """
 
-        def sl(x, y): return self.assertEqual(len(list(x)), y)
+        def sl(x, y):
+            return self.assertEqual(len(list(x)), y)
+
+        def soe(x, y):
+            return self.assertEqual(set([a[2] for a in x]), set(y))  # equals objects
 
-        def soe(x, y): return self.assertEqual(
-            set([a[2] for a in x]), set(y))  # equals objects
         g = self.graph
 
         # Single terms are all trivial:
@@ -27,35 +27,35 @@ class GraphSlice(unittest.TestCase):
 
         # single slice slices by s,p,o, with : used to split
         # tell me everything about "tarek" (same as above)
-        sl(g[self.tarek::], 2)
+        sl(g[self.tarek : :], 2)
 
         # give me every "likes" relationship
-        sl(g[:self.likes:], 5)
+        sl(g[: self.likes :], 5)
 
         # give me every relationship to pizza
-        sl(g[::self.pizza], 3)
+        sl(g[:: self.pizza], 3)
 
         # give me everyone who likes pizza
-        sl(g[:self.likes:self.pizza], 2)
+        sl(g[: self.likes : self.pizza], 2)
 
         # does tarek like pizza?
-        self.assertTrue(g[self.tarek:self.likes:self.pizza])
+        self.assertTrue(g[self.tarek : self.likes : self.pizza])
 
         # More intesting is using paths
 
         # everything hated or liked
-        sl(g[:self.hates | self.likes], 7)
+        sl(g[: self.hates | self.likes], 7)
 
     def setUp(self):
         self.graph = Graph()
 
-        self.michel = URIRef(u'michel')
-        self.tarek = URIRef(u'tarek')
-        self.bob = URIRef(u'bob')
-        self.likes = URIRef(u'likes')
-        self.hates = URIRef(u'hates')
-        self.pizza = URIRef(u'pizza')
-        self.cheese = URIRef(u'cheese')
+        self.michel = URIRef("michel")
+        self.tarek = URIRef("tarek")
+        self.bob = URIRef("bob")
+        self.likes = URIRef("likes")
+        self.hates = URIRef("hates")
+        self.pizza = URIRef("pizza")
+        self.cheese = URIRef("cheese")
 
         self.addStuff()
 
@@ -77,5 +77,5 @@ class GraphSlice(unittest.TestCase):
         self.graph.add((bob, hates, michel))  # gasp!
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
