@@ -1,6 +1,6 @@
 from rdflib import Graph
 
-query_tpl = '''
+query_tpl = """
 SELECT ?x (MIN(?y_) as ?y) (%s(DISTINCT ?z_) as ?z) {
   VALUES (?x ?y_ ?z_) {
     ("x1" 10 1)
@@ -8,12 +8,12 @@ SELECT ?x (MIN(?y_) as ?y) (%s(DISTINCT ?z_) as ?z) {
     ("x2" 20 2)
   }
 } GROUP BY ?x ORDER BY ?x
-'''
+"""
 
 
 def test_group_concat_distinct():
     g = Graph()
-    results = g.query(query_tpl % 'GROUP_CONCAT')
+    results = g.query(query_tpl % "GROUP_CONCAT")
     results = [[lit.toPython() for lit in line] for line in results]
 
     # this is the tricky part
@@ -28,7 +28,7 @@ def test_group_concat_distinct():
 
 def test_sum_distinct():
     g = Graph()
-    results = g.query(query_tpl % 'SUM')
+    results = g.query(query_tpl % "SUM")
     results = [[lit.toPython() for lit in line] for line in results]
 
     # this is the tricky part
@@ -43,7 +43,8 @@ def test_sum_distinct():
 
 def test_avg_distinct():
     g = Graph()
-    results = g.query("""
+    results = g.query(
+        """
         SELECT ?x (MIN(?y_) as ?y) (AVG(DISTINCT ?z_) as ?z) {
           VALUES (?x ?y_ ?z_) {
             ("x1" 10 1)
@@ -52,7 +53,8 @@ def test_avg_distinct():
             ("x2" 20 2)
           }
        } GROUP BY ?x ORDER BY ?x
-    """)
+    """
+    )
     results = [[lit.toPython() for lit in line] for line in results]
 
     # this is the tricky part
@@ -68,7 +70,10 @@ def test_avg_distinct():
 def test_count_distinct():
     g = Graph()
 
-    g.parse(format="turtle", publicID="http://example.org/", data="""
+    g.parse(
+        format="turtle",
+        publicID="http://example.org/",
+        data="""
     @prefix : <> .
 
     <#a>
@@ -83,26 +88,31 @@ def test_count_distinct():
       :knows <#b>, <#c> ;
       :age 20 .
 
-    """)
+    """,
+    )
 
     # Query 1: people knowing someone younger
-    results = g.query("""
+    results = g.query(
+        """
     PREFIX : <http://example.org/>
 
     SELECT DISTINCT ?x {
       ?x :age ?ax ; :knows [ :age ?ay ].
       FILTER( ?ax > ?ay )
     }
-    """)
+    """
+    )
     assert len(results) == 2
 
     # nQuery 2: count people knowing someone younger
-    results = g.query("""
+    results = g.query(
+        """
     PREFIX : <http://example.org/>
 
     SELECT (COUNT(DISTINCT ?x) as ?cx) {
       ?x :age ?ax ; :knows [ :age ?ay ].
       FILTER( ?ax > ?ay )
     }
-    """)
+    """
+    )
     assert list(results)[0][0].toPython() == 2
