@@ -1,3 +1,4 @@
+import pytest
 from rdflib import Graph, Literal, Variable
 
 query_tpl = """
@@ -23,7 +24,7 @@ def template_tst(agg_func, first, second):
     assert results[1][1] == second, (results[1][1], second)
 
 
-def test_aggregates():
+def get_aggregates_tests():
     yield template_tst, "SUM", Literal(0), Literal(42)
     yield template_tst, "MIN", None, Literal(42)
     yield template_tst, "MAX", None, Literal(42)
@@ -33,6 +34,11 @@ def test_aggregates():
     yield template_tst, "GROUP_CONCAT", Literal(""), Literal("42")
 
 
+@pytest.mark.parametrize("checker, agg_func, first, second", get_aggregates_tests())
+def test_aggregates(checker, agg_func, first, second) -> None:
+    checker(agg_func, first, second)
+
+
 def test_group_by_null():
     g = Graph()
     results = list(
