@@ -2,12 +2,16 @@
 
 """
 
+from typing import Callable, Dict
 from rdflib import ConjunctiveGraph
-from rdflib.namespace import split_uri
+from rdflib.namespace import Namespace, split_uri
 from rdflib.compare import graph_diff, isomorphic
+from rdflib.term import Node, URIRef
 
-from test.manifest import nose_tests, RDFT
-from test.testutils import nose_tst_earl_report
+from test.manifest import RDFT, RDFTest, read_manifest
+import pytest
+
+import os
 
 verbose = False
 
@@ -52,34 +56,42 @@ def trig(test):
                     print(t)
                 raise Exception("Graphs do not match!")
 
-            assert isomorphic(g, res), "graphs must be the same"
+            assert isomorphic(
+                g, res
+            ), "graphs must be the same, expected\n%s\n, got\n%s" % (
+                g.serialize(),
+                res.serialize(),
+            )
 
     except:
         if test.syntax:
             raise
 
 
-testers = {
+testers: Dict[Node, Callable[[RDFTest], None]] = {
     RDFT.TestTrigPositiveSyntax: trig,
     RDFT.TestTrigNegativeSyntax: trig,
     RDFT.TestTrigEval: trig,
     RDFT.TestTrigNegativeEval: trig,
 }
 
+NAMESPACE = Namespace(
+    "https://dvcs.w3.org/hg/rdf/raw-file/default/trig/tests/manifest.ttl#"
+)
+EXPECTED_FAILURES: Dict[URIRef, str] = {}
 
-def test_trig(tests=None):
-    for t in nose_tests(testers, "test/w3c/trig/manifest.ttl"):
-        if tests:
-            for test in tests:
-                if test in t[1].uri:
-                    break
-            else:
-                continue
-
-        yield t
+if os.name == "nt":
+    for test in ["literal_with_LINE_FEED", "trig-subm-15", "trig-subm-16"]:
+        EXPECTED_FAILURES[
+            NAMESPACE[test]
+        ] = "Issue with nt parser and line endings on windows"
 
 
-if __name__ == "__main__":
-    verbose = True
-
-    nose_tst_earl_report(test_trig, "rdflib_trig")
+@pytest.mark.parametrize(
+    "rdf_test_uri, type, rdf_test",
+    read_manifest("test/w3c/trig/manifest.ttl"),
+)
+def test_manifest(rdf_test_uri: URIRef, type: Node, rdf_test: RDFTest):
+    if rdf_test_uri in EXPECTED_FAILURES:
+        pytest.xfail(EXPECTED_FAILURES[rdf_test_uri])
+    testers[type](rdf_test)
