@@ -1,10 +1,9 @@
 import unittest
-from six import StringIO
+from io import StringIO
 from rdflib.plugins.sparql.results.tsvresults import TSVResultParser
 
 
 class TestTSVResults(unittest.TestCase):
-
     def test_empty_tsvresults_bindings(self):
         # check that optional bindings are ordered properly
         source = """?s\t?p\t?o
