@@ -17,8 +17,8 @@ https://github.com/RDFLib/rdflib/issues/676
 def test_sort_dates():
 
     g = rdflib.Graph()
-    y = '''@prefix ex: <http://ex.org> .
-ex:X ex:p "2016-01-01T00:00:00"^^<http://www.w3.org/2001/XMLSchema#dateTime>, "2016-01-01T00:00:00Z"^^<http://www.w3.org/2001/XMLSchema#dateTime> . '''
+    y = """@prefix ex: <http://ex.org> .
+ex:X ex:p "2016-01-01T00:00:00"^^<http://www.w3.org/2001/XMLSchema#dateTime>, "2016-01-01T00:00:00Z"^^<http://www.w3.org/2001/XMLSchema#dateTime> . """
 
     p = g.parse(data=y, format="turtle")
     p.serialize(format="turtle")
@@ -27,14 +27,14 @@ ex:X ex:p "2016-01-01T00:00:00"^^<http://www.w3.org/2001/XMLSchema#dateTime>, "2
 def test_sort_docfrag():
 
     g = rdflib.Graph()
-    y = '''@prefix ex: <http://ex.org> .
+    y = """@prefix ex: <http://ex.org> .
 @prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-ex:X ex:p "<h1>hi</h1>"^^rdf:HTML, "<h1>ho</h1>"^^rdf:HTML  . '''
+ex:X ex:p "<h1>hi</h1>"^^rdf:HTML, "<h1>ho</h1>"^^rdf:HTML  . """
 
     p = g.parse(data=y, format="turtle")
     p.serialize(format="turtle")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     test_sort_docfrag()
