@@ -1,5 +1,8 @@
+# -*- coding: utf-8 -*-
+
 import unittest
 import time
+from unittest.case import expectedFailure
 from rdflib.graph import Graph
 from rdflib.graph import QuotedGraph
 from rdflib.graph import ConjunctiveGraph
@@ -11,7 +14,7 @@ from rdflib import XSD
 from rdflib.exceptions import SubjectTypeError
 from rdflib.exceptions import PredicateTypeError
 from rdflib.exceptions import ObjectTypeError
-from rdflib.exceptions import ContextTypeError 
+from rdflib.exceptions import ContextTypeError
 
 n3source = """\
 @prefix : <http://www.w3.org/2000/10/swap/Primer#>.
@@ -47,34 +50,39 @@ n3source = """\
 :Woman = foo:FemaleAdult .
 :Title a rdf:Property; = dc:title .
 
-""" # --- End of primer code
+"""  # --- End of primer code
+
 
 class TestUtilMisc(unittest.TestCase):
     def setUp(self):
-        self.x = Literal("2008-12-01T18:02:00Z",
-                         datatype=URIRef('http://www.w3.org/2001/XMLSchema#dateTime'))
+        self.x = Literal(
+            "2008-12-01T18:02:00Z",
+            datatype=URIRef("http://www.w3.org/2001/XMLSchema#dateTime"),
+        )
 
     def test_util_list2set(self):
-        base = [Literal('foo'), self.x]
-        r = util.list2set(base+base)
+        base = [Literal("foo"), self.x]
+        r = util.list2set(base + base)
         self.assertTrue(r == base)
 
     def test_util_uniq(self):
         base = ["michel", "hates", "pizza"]
-        r = util.uniq(base+base)
+        r = util.uniq(base + base)
         self.assertEqual(sorted(r), sorted(base))
         base = ["michel", "hates", "pizza"]
-        r = util.uniq(base+base, strip=True)
+        r = util.uniq(base + base, strip=True)
         self.assertEqual(sorted(r), sorted(base))
 
     def test_coverage_dodge(self):
         util.test()
 
-class TestUtilDateTime(unittest.TestCase):
 
+class TestUtilDateTime(unittest.TestCase):
     def setUp(self):
-        self.x = Literal("2008-12-01T18:02:00Z",
-                         datatype=URIRef('http://www.w3.org/2001/XMLSchema#dateTime'))
+        self.x = Literal(
+            "2008-12-01T18:02:00Z",
+            datatype=URIRef("http://www.w3.org/2001/XMLSchema#dateTime"),
+        )
 
     def test_util_date_time_tisnoneandnotz(self):
         t = None
@@ -108,18 +116,24 @@ class TestUtilDateTime(unittest.TestCase):
 
     def test_util_date_timewithtoutz(self):
         t = time.time()
+
         def ablocaltime(t):
             from time import gmtime
+
             res = gmtime(t)
             return res
+
         util.localtime = ablocaltime
         res = util.date_time(t, local_time_zone=True)
         self.assertTrue(res is not t)
 
+
 class TestUtilTermConvert(unittest.TestCase):
     def setUp(self):
-        self.x = Literal("2008-12-01T18:02:00Z",
-                         datatype=URIRef('http://www.w3.org/2001/XMLSchema#dateTime'))
+        self.x = Literal(
+            "2008-12-01T18:02:00Z",
+            datatype=URIRef("http://www.w3.org/2001/XMLSchema#dateTime"),
+        )
 
     def test_util_to_term_sisNone(self):
         s = None
@@ -139,12 +153,12 @@ class TestUtilTermConvert(unittest.TestCase):
         self.assertEqual(str(res), s[1:-1])
 
     def test_util_to_term_sisbnode(self):
-        s = '_http%23%4F%4Fexample%33com'
+        s = "_http%23%4F%4Fexample%33com"
         res = util.to_term(s)
         self.assertTrue(isinstance(res, BNode))
 
     def test_util_to_term_sisunknown(self):
-        s = 'http://example.com'
+        s = "http://example.com"
         self.assertRaises(Exception, util.to_term, s)
 
     def test_util_to_term_sisnotstr(self):
@@ -162,7 +176,6 @@ class TestUtilTermConvert(unittest.TestCase):
         default = "TestofDefault"
         res = util.from_n3(s, default=default, backend=None)
         self.assertTrue(res == default)
-    
 
     def test_util_from_n3_expectdefaultbnode(self):
         s = "michel"
@@ -180,7 +193,7 @@ class TestUtilTermConvert(unittest.TestCase):
         self.assertTrue(isinstance(res, Literal))
 
     def test_util_from_n3_expecturiref(self):
-        s = '<http://example.org/schema>'
+        s = "<http://example.org/schema>"
         res = util.from_n3(s, default=None, backend=None)
         self.assertTrue(isinstance(res, URIRef))
 
@@ -193,92 +206,144 @@ class TestUtilTermConvert(unittest.TestCase):
         s = '"michel"@fr^^xsd:fr'
         res = util.from_n3(s, default=None, backend=None)
         self.assertTrue(isinstance(res, Literal))
-        self.assertEqual(res, Literal('michel',
-                                      datatype=XSD['fr']))
+        self.assertEqual(res, Literal("michel", datatype=XSD["fr"]))
 
     def test_util_from_n3_expectliteralanddtype(self):
         s = '"true"^^xsd:boolean'
         res = util.from_n3(s, default=None, backend=None)
-        self.assertTrue(res.eq(Literal('true', datatype=XSD['boolean'])))
+        self.assertTrue(res.eq(Literal("true", datatype=XSD["boolean"])))
 
     def test_util_from_n3_expectliteralwithdatatypefromint(self):
-        s = '42'
+        s = "42"
         res = util.from_n3(s)
         self.assertEqual(res, Literal(42))
-    
+
     def test_util_from_n3_expectliteralwithdatatypefrombool(self):
-        s = 'true'
+        s = "true"
         res = util.from_n3(s)
         self.assertEqual(res, Literal(True))
-        s = 'false'
+        s = "false"
         res = util.from_n3(s)
         self.assertEqual(res, Literal(False))
-    
+
     def test_util_from_n3_expectliteralmultiline(self):
         s = '"""multi\nline\nstring"""@en'
         res = util.from_n3(s, default=None, backend=None)
-        self.assertTrue(res, Literal('multi\nline\nstring', lang='en'))
-    
+        self.assertTrue(res, Literal("multi\nline\nstring", lang="en"))
+
     def test_util_from_n3_expectliteralwithescapedquote(self):
         s = '"\\""'
         res = util.from_n3(s, default=None, backend=None)
-        self.assertTrue(res, Literal('\\"', lang='en'))
+        self.assertTrue(res, Literal('\\"', lang="en"))
 
     def test_util_from_n3_expectliteralwithtrailingbackslash(self):
         s = '"trailing\\\\"^^<http://www.w3.org/2001/XMLSchema#string>'
         res = util.from_n3(s)
-        self.assertTrue(res, Literal('trailing\\', datatype=XSD['string']))
+        self.assertTrue(res, Literal("trailing\\", datatype=XSD["string"]))
         self.assertTrue(res.n3(), s)
-    
+
     def test_util_from_n3_expectpartialidempotencewithn3(self):
-        for n3 in ('<http://ex.com/foo>',
-                   '"foo"@de',
-                   #'"\\""', # exception as '\\"' --> '"' by orig parser as well
-                   '"""multi\n"line"\nstring"""@en'):
-            self.assertEqual(util.from_n3(n3).n3(), n3,
-                             'from_n3(%(n3e)r).n3() != %(n3e)r' % {'n3e': n3})
-    
+        for n3 in (
+            "<http://ex.com/foo>",
+            '"foo"@de',
+            "<http://ex.com/漢字>",
+            "<http://ex.com/a#あ>",
+            # '"\\""', # exception as '\\"' --> '"' by orig parser as well
+            '"""multi\n"line"\nstring"""@en',
+        ):
+            self.assertEqual(
+                util.from_n3(n3).n3(),
+                n3,
+                "from_n3(%(n3e)r).n3() != %(n3e)r" % {"n3e": n3},
+            )
+
     def test_util_from_n3_expectsameasn3parser(self):
         def parse_n3(term_n3):
-            ''' Disclaimer: Quick and dirty hack using the n3 parser. '''
-            prepstr = ("@prefix  xsd: <http://www.w3.org/2001/XMLSchema#> .\n"
-                       "<urn:no_use> <urn:no_use> %s.\n" % term_n3)
+            """Disclaimer: Quick and dirty hack using the n3 parser."""
+            prepstr = (
+                "@prefix  xsd: <http://www.w3.org/2001/XMLSchema#> .\n"
+                "<urn:no_use> <urn:no_use> %s.\n" % term_n3
+            )
             g = ConjunctiveGraph()
-            g.parse(data=prepstr, format='n3')
+            g.parse(data=prepstr, format="n3")
             return [t for t in g.triples((None, None, None))][0][2]
-        
-        for n3 in (# "michel", # won't parse in original parser
-                   # "_:michel", # BNodes won't be the same
-                   '"michel"',
-                   '<http://example.org/schema>',
-                   '"michel"@fr',
-                   # '"michel"@fr^^xsd:fr', # FIXME: invalid n3, orig parser will prefer datatype
-                   # '"true"^^xsd:boolean', # FIXME: orig parser will expand xsd prefix
-                   '42',
-                   'true',
-                   'false',
-                   '"""multi\nline\nstring"""@en',
-                   '<http://ex.com/foo>',
-                   '"foo"@de',
-                   '"\\""@en',
-                   '"""multi\n"line"\nstring"""@en'):
-            res, exp = util.from_n3(n3), parse_n3(n3)
-            self.assertEqual(res, exp,
-                'from_n3(%(n3e)r): %(res)r != parser.notation3: %(exp)r' % {
-                        'res': res, 'exp': exp, 'n3e':n3})
-        
 
+        for n3 in (  # "michel", # won't parse in original parser
+            # "_:michel", # BNodes won't be the same
+            '"michel"',
+            "<http://example.org/schema>",
+            '"michel"@fr',
+            # '"michel"@fr^^xsd:fr', # FIXME: invalid n3, orig parser will prefer datatype
+            # '"true"^^xsd:boolean', # FIXME: orig parser will expand xsd prefix
+            "42",
+            "true",
+            "false",
+            '"""multi\nline\nstring"""@en',
+            "<http://ex.com/foo>",
+            '"foo"@de',
+            '"\\""@en',
+            '"""multi\n"line"\nstring"""@en',
+        ):
+            res, exp = util.from_n3(n3), parse_n3(n3)
+            self.assertEqual(
+                res,
+                exp,
+                "from_n3(%(n3e)r): %(res)r != parser.notation3: %(exp)r"
+                % {"res": res, "exp": exp, "n3e": n3},
+            )
 
     def test_util_from_n3_expectquotedgraph(self):
-        s = '{<http://example.com/schema>}'
-        res = util.from_n3(s, default=None, backend="IOMemory")
+        s = "{<http://example.com/schema>}"
+        res = util.from_n3(s, default=None, backend="Memory")
         self.assertTrue(isinstance(res, QuotedGraph))
 
     def test_util_from_n3_expectgraph(self):
-        s = '[<http://example.com/schema>]'
-        res = util.from_n3(s, default=None, backend="IOMemory")
+        s = "[<http://example.com/schema>]"
+        res = util.from_n3(s, default=None, backend="Memory")
         self.assertTrue(isinstance(res, Graph))
 
+    def test_util_from_n3_escapes(self) -> None:
+        pairs = [
+            ("\\t", "\t"),
+            ("\\b", "\b"),
+            ("\\n", "\n"),
+            ("\\r", "\r"),
+            ("\\f", "\f"),
+            ('\\"', '"'),
+            ("\\'", "'"),
+            ("\\\\", "\\"),
+            ("\\u00F6", "ö"),
+            ("\\U000000F6", "ö"),
+        ]
+        for escaped, raw in pairs:
+            with self.subTest(f"{escaped} => {raw}"):
+                literal_str = str(util.from_n3(f'"{escaped}"'))
+                self.assertEqual(literal_str, f"{raw}")
+
+    def test_util_from_n3_not_escapes(self) -> None:
+        strings = [
+            "jörn",
+            "j\\xf6rn",
+        ]
+        for string in strings:
+            with self.subTest(f"{string}"):
+                literal_str = str(util.from_n3(f'"{string}"'))
+                self.assertEqual(literal_str, f"{string}")
+
+    @expectedFailure
+    def test_util_from_n3_not_escapes_xf(self) -> None:
+        strings = [
+            f"j\\366rn",
+            f"\\",
+            f"\\0",
+            f"\\I",
+        ]
+        for string in strings:
+            with self.subTest(f"{string}"):
+                literal_str = str(util.from_n3(f'"{string}"'))
+                self.assertEqual(literal_str, f"{string}")
+
+
 class TestUtilCheckers(unittest.TestCase):
     def setUp(self):
         self.c = URIRef("http://example.com")
@@ -288,10 +353,10 @@ class TestUtilCheckers(unittest.TestCase):
 
     def test_util_checker_exceptions(self):
         c = "http://example.com"
-        self.assertRaises(ContextTypeError, util.check_context, c) 
-        self.assertRaises(SubjectTypeError, util.check_subject, c) 
-        self.assertRaises(PredicateTypeError, util.check_predicate, c) 
-        self.assertRaises(ObjectTypeError, util.check_object, c) 
+        self.assertRaises(ContextTypeError, util.check_context, c)
+        self.assertRaises(SubjectTypeError, util.check_subject, c)
+        self.assertRaises(PredicateTypeError, util.check_predicate, c)
+        self.assertRaises(ObjectTypeError, util.check_object, c)
 
     def test_util_check_context(self):
         res = util.check_context(self.c)
@@ -300,7 +365,7 @@ class TestUtilCheckers(unittest.TestCase):
     def test_util_check_subject(self):
         res = util.check_subject(self.s)
         self.assertTrue(res == None)
-    
+
     def test_util_check_predicate(self):
         res = util.check_predicate(self.p)
         self.assertTrue(res == None)
@@ -308,41 +373,23 @@ class TestUtilCheckers(unittest.TestCase):
     def test_util_check_object(self):
         res = util.check_object(self.o)
         self.assertTrue(res == None)
-    
+
     def test_util_check_statement(self):
         c = "http://example.com"
-        self.assertRaises(
-            SubjectTypeError, 
-                util.check_statement, 
-                    (c, self.p, self.o)) 
-        self.assertRaises(
-            PredicateTypeError, 
-                util.check_statement, 
-                    (self.s, c, self.o)) 
-        self.assertRaises(
-            ObjectTypeError, 
-                util.check_statement, 
-                    (self.s, self.p, c)) 
+        self.assertRaises(SubjectTypeError, util.check_statement, (c, self.p, self.o))
+        self.assertRaises(PredicateTypeError, util.check_statement, (self.s, c, self.o))
+        self.assertRaises(ObjectTypeError, util.check_statement, (self.s, self.p, c))
         res = util.check_statement((self.s, self.p, self.o))
         self.assertTrue(res == None)
-    
+
     def test_util_check_pattern(self):
         c = "http://example.com"
-        self.assertRaises(
-            SubjectTypeError, 
-                util.check_pattern, 
-                    (c, self.p, self.o)) 
-        self.assertRaises(
-            PredicateTypeError, 
-                util.check_pattern, 
-                    (self.s, c, self.o)) 
-        self.assertRaises(
-            ObjectTypeError, 
-                util.check_pattern, 
-                    (self.s, self.p, c)) 
+        self.assertRaises(SubjectTypeError, util.check_pattern, (c, self.p, self.o))
+        self.assertRaises(PredicateTypeError, util.check_pattern, (self.s, c, self.o))
+        self.assertRaises(ObjectTypeError, util.check_pattern, (self.s, self.p, c))
         res = util.check_pattern((self.s, self.p, self.o))
         self.assertTrue(res == None)
 
+
 if __name__ == "__main__":
     unittest.main()
-
